import { NavLink } from 'react-router'
import facebook from '~/images/facebook.svg'
import instagram from '~/images/instagram.svg'
import logoWhite from '~/images/logo-white.svg'
import { FOOTER_MENU } from '~/menu'
import footerLayer from '~/images/footer-layer.png'

export default function Footer() {
  return (
    <>
      <div className="container mx-auto px-4 relative -mb-14 mt-10 z-10">
        <div className="shadow-2xl bg-white p-4 xl:p-8 rounded-3xl flex justify-around items-center gap-2">
          <h2 className="text-center text-navy font-semibold text-base sm:text-2xl xl:text-3xl max-w-lg">
            Sosyal Medya Hesaplarımızdan Bizi Takip Edin
          </h2>
          <NavLink
            to="/"
            className="size-[40px] sm:size-[80px] xl:size-[110px] rounded-full bg-[#F5F5F5] flex items-center justify-center"
          >
            <img src={facebook} className='sm:size-10 size-5' width={50} height={50} alt="" />
          </NavLink>
          <NavLink
            to="/"
            className="size-[40px] sm:size-[80px] xl:size-[110px] rounded-full bg-[#F5F5F5] flex items-center justify-center"
          >
            <img src={instagram} className='sm:size-10 size-5' width={50} height={50} alt="" />
          </NavLink>
        </div>
      </div>
      <footer className="bg-gradient-to-b from-[#9A090C] to-[#7E2527] w-full relative overflow-hidden">
        <img src={footerLayer} className='absolute left-[-7%] bottom-[-65%] opacity-50' width={800} alt="" />
        <div className="container mx-auto px-4 pt-24 sm:pt-[150px]">
          <div className="grid grid-cols-1 lg:grid-cols-3 gap-4 pb-10 sm:pb-20">
            <div className="col-span-1">
              <NavLink to="/">
                <img src={logoWhite} alt="" className="inline" />
              </NavLink>
            </div>
            <div className="grid grid-cols-1 sm:grid-cols-3 gap-x-4 gap-y-12 lg:col-span-2">
              {FOOTER_MENU.map((menu, i) => (
                <div key={i}>
                  <h3 className="text-white font-bold text-xl">{menu.label}</h3>
                  <ul className="mt-4 space-y-3">
                    {menu.items.map((item, i) => (
                      <li key={i}>
                        <NavLink
                          to={item.url}
                          target={item.target}
                          className="text-white inline-flex items-start gap-1"
                        >
                          {item.icon && (
                            <img src={item.icon} alt="" className="mt-1 inline-block" />
                          )}
                          <div>
                            <p className="m-0">{item.label}</p>
                            {item.subLabel && (
                              <p className="text-white text-xs m-0">{item.subLabel}</p>
                            )}
                          </div>
                        </NavLink>
                      </li>
                    ))}
                  </ul>
                </div>
              ))}
            </div>
          </div>
          <p className="text-white pb-4 font-medium">
            Copyright ©2025 | Benim Ustam Tüm Hakları Saklı
          </p>
        </div>
      </footer>
    </>
  )
}
